@@ -15,6 +15,7 @@ class Instrument:
 	start = 0
 	end = -1
 	step = 0
+	midi_set = False
 	
 	def __init__(self, parameters):
 		self.params = parameters
@@ -30,9 +31,10 @@ class Instrument:
 			self.step = parameters["step"]
 
 	def play(self, state):
-
-		if 'midi_instr' in self.params:
+		
+		if not(self.midi_set) and 'midi_instr' in self.params:
 			fluidsynth.midi.set_instrument(self.params["channel"], self.params["midi_instr"])
+			self.midi_set = True
 
 			
 		if 'let_ring' not in self.params:
